centering: centering

View source: R/niftiFMRI.R

centeringR Documentation

centering

Description

This function center the data in the two dimensions, the first dimension being indicated by col.first argument

Usage

centering(X,col.first=TRUE)

Arguments

X

a matrix of size tm x vm which contains the functionnal images

col.first

Logical. Center the columns or the rows first

Value

Xcentred

the double centered matrix

See Also

reduction

Examples

X <- matrix(rnorm(5 * 4), nrow = 5, ncol = 4)
Xcentred <- centering(X, col.first = TRUE)$Xcentred

AnalyzeFMRI documentation built on June 23, 2026, 5:07 p.m.