eigenvalues: eigenvalues

View source: R/niftiFMRI.R

eigenvaluesR Documentation

eigenvalues

Description

This function computes the eigenvalues of a centered and reduced data matrix

Usage

eigenvalues(X, draw = FALSE)

Arguments

X

a matrix of size tm x vm which contains the functionnal images centered and reduced

draw

Logical. Should we plot the eigenvalues

Value

A list containing

eigenvalues

vector of the eigenvalues

Examples

X <- matrix(rnorm(5 * 4), nrow = 5, ncol = 4)
Xc <- centering(X, col.first = TRUE)$Xcentred
Xcr <- reduction(Xc, row.red = FALSE)$Xred
eigencr <- eigenvalues(Xcr, draw = FALSE)$eigenvalues

AnalyzeFMRI documentation built on June 23, 2026, 5:07 p.m.