f.read.analyze.tpt: Read in a volume at one time point

View source: R/analyzeFMRI.R

f.read.analyze.tptR Documentation

Read in a volume at one time point

Description

Given a 4D ANALYZE .img/.hdr image pair this function can read in the 3D volume of measurements at a specific time point.

Usage

f.read.analyze.tpt(file, tpt)

Arguments

file

The .img file.

tpt

The time point to read in.

Details

Given a 4D ANALYZE .img/.hdr image pair this function can read in the 3D volume of measurements at a specific time point.

Value

A 3D array containing the volume.

See Also

f.read.analyze.slice, f.read.analyze.slice.at.all.timepoints, f.write.analyze,

Examples

a <- f.read.analyze.tpt(system.file("example.img", package = "AnalyzeFMRI"), 1)

AnalyzeFMRI documentation built on June 23, 2026, 5:07 p.m.