xyzt2st: xyzt2st

View source: R/niftiFMRI.R

xyzt2stR Documentation

xyzt2st

Description

Extract space and time dimension codes from the one byte xyzt.units field of a NIFTI header file.

Usage

xyzt2st(xyzt.units, verbose = TRUE)

Arguments

xyzt.units

xyzt.units field of a NIFTI header file

verbose

verbose logical to display information about the units

Value

A list containing space and time fields.

See also the Value Section of the help file of function st2xyzt().

See Also

st2xyzt

Examples

xyzt.units <- f.read.header(system.file("example-nifti.hdr", package="AnalyzeFMRI"))$xyzt.units
xyzt2st(xyzt.units)

AnalyzeFMRI documentation built on June 23, 2026, 5:07 p.m.